#!/bin/sh

# This script runs orca_services.pl with the proper options for your
# site.

# Define program locations that will be needed.
prefix=/usr/local/orca-0.27
exec_prefix=${prefix}
libdir=${exec_prefix}/lib
AWK=/usr/bin/nawk
CUT=/usr/bin/cut
UNAME=/usr/bin/uname
ORCA_SERVICES_DIR=/usr/local/orca-0.27/var/orca/orca_services

# Get the hostname without the fully qualified part; that is, trim off
# anything past the first `.'.
uname=`$UNAME -n | $CUT -d. -f1`

# The directory these files go into is $ORCA_SERVICES_DIR/HOSTNAME.
OUTDIR=$ORCA_SERVICES_DIR/$uname

# Export the environmental variables.
export OUTDIR

# Check if orca_services is already running.
pids=`/usr/ucb/ps auxww | $AWK '/orca_services.pl/ && !/awk/ {print $2}'`
if test "$pids" != ""; then
  echo "Orca_services already running.  Exiting."
  exit 1
fi

echo "Writing data into $OUTDIR/"

# Cd to / so that any automounted filesystems can be unmounted.
cd /

# Create the output directory if it doesn't exist yet.
if test ! -d $OUTDIR; then
  echo "Creating $OUTDIR/"
  mkdir -p $OUTDIR
fi

if test ! -d $OUTDIR; then
  echo "Unable to create $OUTDIR/" 1>&2
  exit 2
fi

# Now start the logging.
echo "Starting logging"
HOSTNAME=`hostname`
if test -f "$libdir/orca_services.$HOSTNAME"; then
  $libdir/orca_services.pl `cat $libdir/orca_services.$HOSTNAME`
else
  $libdir/orca_services.pl
fi

### # Write the PID of orca_services to a file to make killing easier.
### pid=$!
### echo $pid > $OUTDIR/orca_services.pid

# Sleep for a couple of seconds to allow any orca_services warnings to
# appear.
sleep 5
